@@ -43,8 +43,8 @@ individual_differences <- function(dataSrc, predicate = NULL)
   observed = parms$inputs$scoretab$N
   m = sum(observed)
   lambda = parms$est$lambda$lambda
-  observed_smooth = ENORM2ScoreDist(b,a,lambda,first,last,observed)$n.smooth
-  
+  observed_smooth = ENORM2ScoreDist(b,a,lambda,first,last)$n.smooth
+
   theta.est = theta_score_distribution(b,a,first,last,observed)
   expected = pscore(theta.est,b,a,first,last)[,1,drop=TRUE]
   chi = chisq.test(x=observed,p=expected,simulate.p.value = TRUE)
@@ -88,7 +88,7 @@ plot.tind=function(x,...)
   do.call(plot,merge_arglists(user.args,override=override.args, default=default.args))
 
   lines(0:x$inputs$max.score,x$est$test$expected,col="gray",pch=19,cex=0.7)
- # lines(0:x$inputs$max.score,x$inputs$observed_smooth,col="lightgreen")
+  lines(0:x$inputs$max.score,x$inputs$observed_smooth,col="lightgreen")
   legend("topleft", legend = c("observed", "expected"), bty = "n",
          lwd = 1, cex = 0.7, col = c("#4DAF4A", "gray"), lty = c(NA,1), pch = c(19,NA))
 }
\ No newline at end of file
